.. Stetl documentation master file, created by
   sphinx-quickstart on Sun Jun  2 11:01:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Stetl
================

Stetl, Streaming ETL, is an open source (GNU GPL) toolkit for the transformation (ETL)
of geospatial data.  Stetl is based on existing ETL tools like GDAL/OGR and
XSLT. Stetl processing is driven from a configuration (.ini) file.
Stetl is written in Python and in particular suited for processing GML.

This is the documentation of the Stetl toolkit.
The code is on GitHub: https://github.com/geopython/stetl. Since July 2016 the project is a proud
member of the `GeoPython GitHub organization <https://github.com/geopython>`_.

See an `introductory Stetl presentation on Slideshare <http://www.slideshare.net/justb4/geospatial-etl-with-stetl-geopython-2016>`_.

This is document version |release| generated on |today|.

Contents:

.. toctree::
   :maxdepth: 1

   intro.rst
   install.rst
   py3upgrade.rst
   background.rst
   using.rst
   cases.rst
   code.rst
   contact.rst
   links.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

